@@ -4,6 +4,7 @@ from typing import Any, List, Optional, Tuple, Union
 import pandas as pd
 
 from pandas_profiling.config import Correlation, Settings
+from pandas_profiling.model.alerts import Alert
 from pandas_profiling.profile_report import ProfileReport
 
 
@@ -220,6 +221,30 @@ def _apply_config(description: dict, config: Settings) -> dict:
     return description
 
 
+def _is_alert_present(alert: Alert, alert_list: list) -> bool:
+    return any(
+        a.column_name == alert.column_name and a.alert_type == alert.alert_type
+        for a in alert_list
+    )
+
+
+def _create_placehoder_alerts(report_alerts: tuple) -> tuple:
+    from copy import copy
+
+    fixed: list = [[] for _ in report_alerts]
+    for idx, alerts in enumerate(report_alerts):
+        for alert in alerts:
+            fixed[idx].append(alert)
+            for i, fix in enumerate(fixed):
+                if i == idx:
+                    continue
+                if not _is_alert_present(alert, report_alerts[i]):
+                    empty_alert = copy(alert)
+                    empty_alert._is_empty = True
+                    fix.append(empty_alert)
+    return tuple(fixed)
+
+
 def compare(
     reports: List[ProfileReport],
     config: Optional[Settings] = None,
@@ -279,7 +304,7 @@ def compare(
         res = _update_merge(res, r)
 
     res["analysis"]["title"] = _compare_title(res["analysis"]["title"])
-
+    res["alerts"] = _create_placehoder_alerts(res["alerts"])
     profile = ProfileReport(None, config=_config)
     profile._description_set = res
     return profile
